@@ -41,6 +41,9 @@ SUPPORTED_MODES = tuple(set(SPARK_MODES + SPARK_STREAMING_MODES + POLARS_DELTA_M
 class BaseDataSink(BaseModel, PipelineChild):
     """Base class for data sinks"""
 
+    databricks_quality_monitor: Literal[None] = Field(
+        None, description="Databricks Quality Monitor"
+    )
     checkpoint_path_: str | Path = Field(
         None,
         description="Path to which the checkpoint file for which a streaming dataframe should be written.",
@@ -54,6 +57,7 @@ class BaseDataSink(BaseModel, PipelineChild):
     type: Literal["FILE", "HIVE_METASTORE", "UNITY_CATALOG"] = Field(
         ..., description="Name of the data sink type"
     )
+    metadata: Literal[None] = Field(None, description="Table and columns metadata.")
     merge_cdc_options: DataSinkMergeCDCOptions = Field(
         None,
         description="Merge options to handle input DataFrames that are Change Data Capture (CDC). Only used when `MERGE` mode is selected.",
@@ -175,9 +179,18 @@ class BaseDataSink(BaseModel, PipelineChild):
     def is_cdc(self) -> bool:
         return self.merge_cdc_options is not None
 
+    @property
+    def dlt_pre_merge_view_name(self):
+        """
+        DLT view applying node transformer prior to applying CDC changes.
+        """
+        return "_" + self.dlt_table_or_view_name.split(".")[-1]
+
     @property
     def dlt_apply_changes_kwargs(self) -> dict[str, str]:
-        """Keyword arguments for dlt.apply_changes function"""
+        """
+        Keyword arguments for dlt.apply_changes function
+        """
 
         # if not isinstance(self, TableDataSink):
         #     raise ValueError("DLT only supports `TableDataSink` class")
@@ -191,7 +204,7 @@ class BaseDataSink(BaseModel, PipelineChild):
             "ignore_null_updates": cdc.ignore_null_updates,
             "keys": cdc.primary_keys,
             "sequence_by": cdc.order_by,
-            # "source": self.source.table_name,  # TO SET EXTERNALLY
+            "source": self.dlt_pre_merge_view_name,
             "stored_as_scd_type": cdc.scd_type,
             "target": self.table_name,
             # "track_history_column_list": cdc.track_history_columns,  # NOT SUPPORTED
