@@ -13,8 +13,11 @@ from pydantic import model_validator
 
 from laktory._logger import get_logger
 from laktory._settings import settings
+from laktory.models import UnityCatalogDataSink
 from laktory.models.basemodel import BaseModel
 from laktory.models.dataquality.check import DataQualityCheck
+from laktory.models.pipeline._execute import _execute  # noqa: F401
+from laktory.models.pipeline._post_execute import _post_execute  # noqa: F401
 from laktory.models.pipeline.orchestrators.databricksjoborchestrator import (
     DatabricksJobOrchestrator,
 )
@@ -28,6 +31,7 @@ from laktory.models.resources.terraformresource import TerraformResource
 from laktory.typing import AnyFrame
 
 if TYPE_CHECKING:
+    from databricks.sdk import WorkspaceClient
     from plotly.graph_objs import Figure
 
 logger = get_logger(__name__)
@@ -73,68 +77,6 @@ def parse_requirement_name(req: str) -> str | None:
     return None
 
 
-def _read_and_execute():
-    """Execute pipeline as a script"""
-    # TODO: Refactor and integrate into dispatcher / executor / CLI
-
-    import argparse
-
-    import laktory as lk
-
-    # Parse arguments
-    parser = argparse.ArgumentParser(
-        description="Read pipeline configuration file and execute"
-    )
-    parser.add_argument(
-        "--filepath", type=str, help="Laktory branch name", required=True
-    )
-    parser.add_argument(
-        "--node_name",
-        type=str,
-        help="Node name",
-        default=None,
-        required=False,
-    )
-    parser.add_argument(
-        "--full_refresh",
-        type=str2bool,
-        help="Full refresh",
-        default=False,
-        required=False,
-    )
-
-    # Get arguments
-    args = parser.parse_args()
-    filepath = args.filepath
-    node_name = args.node_name
-    full_refresh = args.full_refresh
-    node_str = ""
-    if node_name:
-        node_str = f" node '{node_name}' of "
-    logger.info(
-        f"Executing{node_str} pipeline '{filepath}' with full refresh {full_refresh}"
-    )
-
-    # Read
-    with open(filepath, "r") as fp:
-        if str(filepath).endswith(".yaml"):
-            pl = lk.models.Pipeline.model_validate_yaml(fp)
-        else:
-            pl = lk.models.Pipeline.model_validate_json(fp.read())
-
-    # Execute
-    if node_name:
-        pl.nodes_dict[node_name].execute(full_refresh=full_refresh)
-    else:
-        pl.execute(full_refresh=full_refresh)
-
-
-def _read_and_execute_dlt():
-    """Execute pipeline as a script"""
-    # TODO: Add DLT notebook content
-    raise NotImplementedError()
-
-
 # --------------------------------------------------------------------------- #
 # Main Class                                                                  #
 # --------------------------------------------------------------------------- #
@@ -326,6 +268,10 @@ class Pipeline(BaseModel, PulumiResource, TerraformResource, PipelineChild):
         validation_alias=AliasChoices("root_path", "root_path_"),
         exclude=True,
     )
+    databricks_quality_monitor_enabled: bool = Field(
+        False,
+        description="Enable Databricks Quality Monitor. When enabled, quality monitors are created for each sink configured with a quality monitor and deleted for sinks without.",
+    )
     _imports_imported: bool = False
 
     @model_validator(mode="before")
@@ -583,6 +529,7 @@ class Pipeline(BaseModel, PulumiResource, TerraformResource, PipelineChild):
         write_sinks=True,
         full_refresh: bool = False,
         named_dfs: dict[str, AnyFrame] = None,
+        update_tables_metadata: bool = True,
     ) -> None:
         """
         Execute the pipeline (read sources and write sinks) by sequentially
@@ -598,6 +545,8 @@ class Pipeline(BaseModel, PulumiResource, TerraformResource, PipelineChild):
             existing data and checkpoints before processing.
         named_dfs:
             Named DataFrames to be passed to pipeline nodes transformer.
+        update_tables_metadata:
+            Update tables metadata
         """
         logger.info("Executing Pipeline")
 
@@ -609,8 +558,49 @@ class Pipeline(BaseModel, PulumiResource, TerraformResource, PipelineChild):
                 write_sinks=write_sinks,
                 full_refresh=full_refresh,
                 named_dfs=named_dfs,
+                update_tables_metadata=update_tables_metadata,
             )
 
+    def update_tables_metadata(self):
+        logger.info("Updating pipeline tables metadata")
+
+        for inode, node in enumerate(self.sorted_nodes):
+            for s in node.sinks:
+                if s.metadata:
+                    s.metadata.execute()
+
+    def update_quality_monitors(self, workspace_client: "WorkspaceClient" = None):
+        if not self.databricks_quality_monitor_enabled:
+            logger.info(
+                f"Databricks Quality Monitor is disabled for pipeline {self.name}. Skipping update."
+            )
+
+        logger.info("Updating pipeline quality monitors")
+        for inode, node in enumerate(self.sorted_nodes):
+            for s in node.sinks:
+                if not isinstance(s, UnityCatalogDataSink):
+                    continue
+
+                if s.databricks_quality_monitor:
+                    sdk = s.databricks_quality_monitor.sdk(
+                        workspace_client=workspace_client
+                    )
+                    sdk.create_or_update()
+                else:
+                    from laktory.models.resources.databricks import QualityMonitor
+
+                    # Create a dummy quality monitor to access the delete function
+                    # Current quality monitor properties will be used to delete
+                    # existing assets.
+                    qm = QualityMonitor(
+                        table_name=s.full_name,
+                        output_schema_name="dummy_schema",
+                        assets_dir="dummy_path",
+                        snapshot={},
+                    )
+                    sdk = qm.sdk(workspace_client=workspace_client)
+                    sdk.delete()
+
     def dag_figure(self) -> "Figure":
         """
         [UNDER DEVELOPMENT] Generate a figure representation of the pipeline
