@@ -513,6 +513,7 @@ class PipelineNode(BaseModel, PipelineChild):
         write_sinks: bool = True,
         full_refresh: bool = False,
         named_dfs: dict[str, AnyFrame] = None,
+        update_tables_metadata: bool = True,
     ) -> AnyFrame:
         """
         Execute pipeline node by:
@@ -533,6 +534,8 @@ class PipelineNode(BaseModel, PipelineChild):
             existing data and checkpoint before processing.
         named_dfs:
             Named DataFrame passed to transformer nodes
+        update_tables_metadata:
+            Update tables metadata
 
         Returns
         -------
@@ -593,6 +596,12 @@ class PipelineNode(BaseModel, PipelineChild):
                 for s in self.quarantine_sinks:
                     s.write(self._quarantine_df, full_refresh=full_refresh)
 
+        # Update tables metadata
+        if update_tables_metadata and not self.is_dlt_execute:
+            for s in self.all_sinks:
+                if s.metadata:
+                    s.metadata.execute()
+
         return self._output_df
 
     def check_expectations(self):
